@@ -347,6 +347,12 @@ def _generate_coverage_data(
     active_fn_name: Optional[str] = None
     first_source = source_map[0]
 
+    while source_map and source_map[-1][2] == -1:
+        # trim the end of the source map where there are no contracts associated
+        # this is required because sometimes the source map is too long
+        # likely a side effect of the YUL optimizer ¯\_(ツ)_/¯
+        source_map.pop()
+
     while source_map:
         # format of source_map is [start, stop, contract_id, jump code]
         source = source_map.popleft()
@@ -367,7 +373,7 @@ def _generate_coverage_data(
             pc_list[-1]["jump"] = source[3]
 
         pc += 1
-        if opcodes[0][:2] == "0x":
+        if pc_list[-1]["op"].startswith("PUSH") and opcodes[0][:2] == "0x":
             pc_list[-1]["value"] = opcodes.popleft()
             pc += int(pc_list[-1]["op"][4:])
 
@@ -463,7 +469,7 @@ def _generate_coverage_data(
         # necessary because sometimes solidity returns an incomplete source map
         pc_list.append({"op": opcodes.popleft(), "pc": pc})
         pc += 1
-        if opcodes and opcodes[0][:2] == "0x":
+        if pc_list[-1]["op"].startswith("PUSH") and opcodes[0][:2] == "0x":
             pc_list[-1]["value"] = opcodes.popleft()
             pc += int(pc_list[-1]["op"][4:])
 
